==> manaplus_1.4.3.29.orig.tar.xz: manaplus-1.4.3.29/src/gui/widgets/tabs/guildchattab.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WIDGETS_TABS_GUILDCHATTAB_H
#define GUI_WIDGETS_TABS_GUILDCHATTAB_H

#include "gui/widgets/tabs/chattab.h"

/**
 * A tab for a guild chat channel.
 */
class GuildChatTab final : public ChatTab,
                           public ConfigListener
{
    public:
        explicit GuildChatTab(const Widget2 *const widget);

        A_DELETE_COPY(GuildChatTab)

        ~GuildChatTab();

        bool handleCommand(const std::string &restrict type,
                           const std::string &restrict args) override final;

        void saveToLogFile(const std::string &msg) const override final;

        int getType() const override A_WARN_UNUSED
        { return ChatTab::TAB_GUILD; }

        void playNewMessageSound() const override final;

        void optionChanged(const std::string &value) override final;

    protected:
        void handleInput(const std::string &msg) override final;

        void getAutoCompleteList(StringVect &names) const override final;

        void getAutoCompleteCommands(StringVect &names) const override final;
};

#endif  // GUI_WIDGETS_TABS_GUILDCHATTAB_H

==> manaplus_1.4.7.19.orig.tar.xz: manaplus-1.4.7.19/src/gui/widgets/tabs/guildchattab.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2014  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WIDGETS_TABS_GUILDCHATTAB_H
#define GUI_WIDGETS_TABS_GUILDCHATTAB_H

#include "gui/widgets/tabs/chattab.h"
#include "gui/widgets/tabs/chattabtype.h"

/**
 * A tab for a guild chat channel.
 */
class GuildChatTab final : public ChatTab,
                           public ConfigListener
{
    public:
        explicit GuildChatTab(const Widget2 *const widget);

        A_DELETE_COPY(GuildChatTab)

        ~GuildChatTab();

        bool handleCommand(const std::string &restrict type,
                           const std::string &restrict args) override final;

        void saveToLogFile(const std::string &msg) const override final;

        int getType() const override A_WARN_UNUSED
        { return ChatTabType::GUILD; }

        void playNewMessageSound() const override final;

        void optionChanged(const std::string &value) override final;

    protected:
        void handleInput(const std::string &msg) override final;

        void getAutoCompleteList(StringVect &names) const override final;

        void getAutoCompleteCommands(StringVect &names) const override final;
};

#endif  // GUI_WIDGETS_TABS_GUILDCHATTAB_H
